@@ -1,6 +1,6 @@
 package Simo::Util;
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0401';
 
 use warnings;
 use strict;
@@ -436,11 +436,17 @@ sub o{
 
 =head1 NAME
 
-Simo::Util - Utility Class for Simo
+Simo::Util - Utility for Simo [DISCOURAGED]
+
+=head1 CAUTION
+
+This module is discouraged now, because I develope new module L<Object::Simple> now.
+
+L<Object::Simple> is very simple class builder. It is clean, compact, and fast.
 
 =head1 VERSION
 
-Version 0.0301
+Version 0.0401
 
 =cut
 
